A data set containing the scenario codes, names short names used in the Wittgenstein Centre Human Capital Data Explorer
wic_scenariosA data frame with 9 rows and 6 variables, including:
Full scenario name
Code to match help file of get_wcde function
Short scenario name
Availability of area in Version 3
Availability of area in Version 2
Availability of area in Version 1